==> wmc_plugin-1.0.0.tar.gz: lib/wmc_plugin.dart <==
import 'dart:async';
import 'dart:typed_data';
import 'package:flutter/services.dart';

class WmcPlugin {
  static const MethodChannel _channel =
      const MethodChannel('wmc_plugin');

  /*
   * Inicializacion de WMC
   */
  static Future<String> initialize(String apikey) async { 
    String _result;
    try {
      final String result =
            await _channel.invokeMethod('initialize',{"apiKey":apikey});
             
      _result = result;
    } on PlatformException catch (e) {
      _result = "${e.message}";
    }  
    return _result;
  }

  /*
   * Método que realiza una solicitud request (POST,GET,PUT,DELETE)
   */
  static Future<String> request(String uri,String method,Map options,Map data) async { 
      String _result;
      try {
        final String result =
              await _channel.invokeMethod('request',{
              "uri":uri,
              "method":method,
              "options":options,
              "data": data
          });
              
        _result = result;
      } on PlatformException catch (e) {
        _result = "${e.message}";
      }  
      return _result;
    }
   /*
   * Método que obtiene la información en bytes de un recursos (Imagen)
   */
  static Future<Uint8List> resource(String uri) async { 
    Uint8List _result;
    try {
      final Uint8List result =
            await _channel.invokeMethod('initialize',{"uri":uri});
             
      _result = result;
    } on PlatformException catch (e) {
      _result = null;
    }
    return _result;
  }
}

==> wmc_plugin-1.0.2.tar.gz: lib/wmc_plugin.dart <==
import 'dart:async';
import 'dart:typed_data';
import 'package:flutter/services.dart';

class WmcPlugin {
  static const MethodChannel _channel =
      const MethodChannel('wmc_plugin');

  /*
   * Inicializacion de WMC
   */
  static Future<String> initialize(String apikey) async { 
    String _result;
    try {
      final String result =
            await _channel.invokeMethod('initialize',{"apiKey":apikey});
             
      _result = result;
    } on PlatformException catch (e) {
      _result = "${e.message}";
    }  
    return _result;
  }

  /*
   * Método que realiza una solicitud request (GET,DELETE)
   */
  static Future<String> request(String uri,String method,Map options,Map data) async { 
      String _result;
      try {
        final String result =
              await _channel.invokeMethod('request',{
              "uri":uri,
              "method":method,
              "options":options,
              "data": data
          });
              
        _result = result;
      } on PlatformException catch (e) {
        _result = "${e.message}";
      }  
      return _result;
    }
  /*
   * Método que realiza una solicitud POST
   */

  static Future<String> post(String uri,Map options,String json) async { 
      String _result;
      try {
        final String result =
              await _channel.invokeMethod('post',{
              "uri":uri,
              "options":options,
              "data": json
          });
              
        _result = result;
      } on PlatformException catch (e) {
        _result = "${e.message}";
      }  
      return _result;
    }


  /*
   * Método que realiza una solicitud PUT
   */

  static Future<String> put(String uri,Map options,String json) async { 
      String _result;
      try {
        final String result =
              await _channel.invokeMethod('put',{
              "uri":uri,
              "options":options,
              "data": json
          });
              
        _result = result;
      } on PlatformException catch (e) {
        _result = "${e.message}";
      }  
      return _result;
    }

    

    
   /*
   * Método que obtiene la información en bytes de un recursos (Imagen)
   */
  static Future<Uint8List> resource(String uri) async { 
    Uint8List _result;
    try {
      final Uint8List result =
            await _channel.invokeMethod('resource',{"uri":uri});
             
      _result = result;
    } on PlatformException catch (e) {
      _result = null;
    }
    return _result;
  }
}
